var indexSectionsWithContent =
{
  0: "_abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefghiklmnopqrstuvwz",
  2: "aops",
  3: "abdehimnoprstv",
  4: "_abcdefghiklmnopqrstuvwxyz~",
  5: "_abcdefghiklmnopqrstuvwxyz",
  6: "_abcdefghiklmnopqrstuvwz",
  7: "abcdefghilmnopqrstuvw",
  8: "_abcdefghijklmnopqrstuvwz",
  9: "cdlnps",
  10: "ago",
  11: "_abcdeghmnorsw",
  12: "abcdefgilmoprstv",
  13: "abcdefghilmoprstuvwy"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "properties",
  10: "related",
  11: "defines",
  12: "groups",
  13: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Properties",
  10: "Friends",
  11: "Macros",
  12: "Modules",
  13: "Pages"
};

